# Cli

[Tstickers Index](../README.md#tstickers-index) / [Tstickers](./index.md#tstickers) / Cli

> Auto-generated documentation for [tstickers.cli](../../../tstickers/cli.py) module.

- [Cli](#cli)
  - [cli](#cli)

## cli

[Show source in cli.py:20](../../../tstickers/cli.py#L20)

Cli entry point.

#### Signature

```python
def cli() -> None: ...
```